import { ICreateCurserDTO } from "@modules/curses/dtos/ICreateCurserDTO";
import { Curser } from "@prisma/client";
import { ICursersRepository } from "../ICursersRepository";
import prismaClient from "@shared/infra/prisma";

class CurserRepository implements ICursersRepository {
    async create({ title, information }: ICreateCurserDTO): Promise<Curser> {
        const curser = await prismaClient.curser.create({
            data: {
                title,
                information
            }
        })

        return curser;
    }

    async findById(id: string): Promise<Curser> {
        const curser = await prismaClient.curser.findUnique({
            where: { id }
        })

        return curser as Curser
    }

    async findByTitle(title: string): Promise<Curser> {
        const curser = await prismaClient.curser.findFirst({
            where: { title }
        })

        return curser as Curser
    }

    async findAllCursers(): Promise<Curser[]> {
        const cursers = await prismaClient.curser.findMany()
        return cursers
    }

    async deleteCurser(id: string): Promise<Boolean> {
        await prismaClient.curser.delete({
            where: { id }
        })

        return true
    }
}

export { CurserRepository }