import { ICreateMessageDTO } from "@modules/messages/dtos/ICreateMessageDTO";
import { Message } from "@prisma/client";
import prismaClient from "@shared/infra/prisma";
import { IMessagesRepository } from "../IMessagesRepository";

class MessageRepository implements IMessagesRepository {
    async create({ message, forum_id }: ICreateMessageDTO): Promise<Message> {
        const messagem = await prismaClient.message.create({
            data: {
                message,
                forum_id
            }
        })

        return messagem
    }

    async findById(id: string): Promise<Message | null> {
        const messagem = await prismaClient.message.findFirst({
            where: { id }
        })

        return messagem as Message
    }

    async delete(id: string): Promise<void> {
        await prismaClient.message.delete({
            where: { id }
        })
    }

    async findByForum(forum_id: string): Promise<Message[]> {
        const messages = await prismaClient.message.findMany({
            where: { forum_id }
        })

        return messages
    }

}

export { MessageRepository }